@@ -1,11 +1,14 @@
 """Python methods for interactive with a Pact Mock Service."""
+from .broker import Broker
 from .consumer import Consumer
 from .matchers import EachLike, Like, SomethingLike, Term, Format
+from .message_pact import MessagePact
+from .message_consumer import MessageConsumer
 from .pact import Pact
 from .provider import Provider
 from .verifier import Verifier
 
 from .__version__ import __version__  # noqa: F401
 
-__all__ = ('Consumer', 'EachLike', 'Like', 'Pact', 'Provider', 'SomethingLike',
-           'Term', 'Format', 'Verifier')
+__all__ = ('Broker', 'Consumer', 'EachLike', 'Like', 'MessageConsumer', 'MessagePact',
+           'Pact', 'Provider', 'SomethingLike', 'Term', 'Format', 'Verifier')
